def 秒数转时间字符串(秒数: int) -> str:
    """
    将秒数转换为标准时间字符串（HH:MM:SS）。

    功能说明：
        - 支持大于24小时的情况，自动累加小时。
        - 秒数为负时会自动取绝对值。
        - 常用于运行时间统计、倒计时显示等。

    Args:
        秒数 (int): 要转换的总秒数。

    Returns:
        str: 形如 "01:23:45" 的时间字符串。
    """
    try:
        秒数 = abs(int(秒数))
        小时, 余数 = divmod(秒数, 3600)
        分钟, 秒 = divmod(余数, 60)
        return f"{小时:02}:{分钟:02}:{秒:02}"
    except Exception:
        return "00:00:00"