def 生成_键值对(键名: str, 值):
    """
    根据给定的键名和值生成一个标准的字典结构。

    功能说明：
        快速构造一个简单的键值对字典，等价于：
            {键名: 值}
        常用于动态构建 JSON 数据、参数拼装、字段生成等场景。

        注意事项：
            - 键名必须是可哈希（hashable）的对象，最常见也是最推荐的类型为 str。
              若键名为 list、dict 等不可哈希类型，将会导致构建字典失败。
            - 值可以为任意类型（字符串、数字、列表、字典、None 等）。
            - 若发生异常（通常由非法键名导致），本函数将返回空字典 {}，
              以避免程序中断。

    Args:
        键名 (str): 字典的键名称，必须是可哈希类型。
        值: 任意类型，用作字典的值。

    Returns:
        dict: 正常情况返回 {键名: 值}；
              若出现异常，则返回空字典 {}。
    """
    try:
        return {键名: 值}
    except Exception:
        return {}