from typing import Any, Dict


def 确保为字典(数据: Any) -> Dict[str, Any]:
    """
    确保返回值为字典类型。

    本函数用于对不确定来源的数据进行防御性处理，
    保证返回结果始终为一个可用的字典对象。

    设计特性：
        - 若传入对象本身为 dict，直接原样返回；
        - 若传入对象不是 dict，返回一个新的空字典；
        - 不对原数据做任何修改或转换尝试；
        - 不抛出任何异常，适合作为底层防御型工具函数。

    行为说明：
        - 数据为 dict      → 原样返回该字典；
        - 数据非 dict      → 返回 {}；
        - 数据为 None      → 返回 {}。

    设计取舍说明：
        - 本函数不尝试将 list、tuple、JSON 字符串等
          “强行转换”为 dict；
        - 若需要转换行为，应由更高层、语义更明确的函数负责；
        - 本函数的职责仅限于“兜底保证类型正确”。

    Args:
        数据: 任意类型的输入数据，来源可能不受信任。

    Returns:
        dict[str, Any]:
            - 成功：返回一个可用的字典对象（原始或新建）；
            - 兜底：返回空字典 {}。
    """
    try:
        if isinstance(数据, dict):
            return 数据
        return {}
    except Exception:
        return {}
