货币代码_人民币 = "CNY"  # 人民币
货币代码_美元 = "USD"  # 美元
货币代码_欧元 = "EUR"  # 欧元
货币代码_日元 = "JPY"  # 日元
货币代码_英镑 = "GBP"  # 英镑
货币代码_澳大利亚元 = "AUD"  # 澳大利亚元
货币代码_加拿大元 = "CAD"  # 加拿大元
货币代码_瑞士法郎 = "CHF"  # 瑞士法郎
货币代码_新西兰元 = "NZD"  # 新西兰元
货币代码_港元 = "HKD"  # 港元
货币代码_新加坡元 = "SGD"  # 新加坡元
货币代码_韩元 = "KRW"  # 韩元
货币代码_印度卢比 = "INR"  # 印度卢比
货币代码_俄罗斯卢布 = "RUB"  # 俄罗斯卢布
货币代码_巴西雷亚尔 = "BRL"  # 巴西雷亚尔
货币代码_南非兰特 = "ZAR"  # 南非兰特
货币代码_土耳其里拉 = "TRY"  # 土耳其里拉
货币代码_墨西哥比索 = "MXN"  # 墨西哥比索
货币代码_挪威克朗 = "NOK"  # 挪威克朗
货币代码_瑞典克朗 = "SEK"  # 瑞典克朗
货币代码_丹麦克朗 = "DKK"  # 丹麦克朗
货币代码_波兰兹罗提 = "PLN"  # 波兰兹罗提
货币代码_匈牙利福林 = "HUF"  # 匈牙利福林
货币代码_捷克克朗 = "CZK"  # 捷克克朗
货币代码_以色列新谢克尔 = "ILS"  # 以色列新谢克尔
货币代码_沙特里亚尔 = "SAR"  # 沙特里亚尔
货币代码_阿联酋迪拉姆 = "AED"  # 阿联酋迪拉姆
货币代码_马来西亚林吉特 = "MYR"  # 马来西亚林吉特
货币代码_泰铢 = "THB"  # 泰铢
货币代码_印尼盾 = "IDR"  # 印尼盾
货币代码_菲律宾比索 = "PHP"  # 菲律宾比索
货币代码_越南盾 = "VND"  # 越南盾
货币代码_尼日利亚奈拉 = "NGN"  # 尼日利亚奈拉
货币代码_埃及镑 = "EGP"  # 埃及镑
货币代码_肯尼亚先令 = "KES"  # 肯尼亚先令
货币代码_阿根廷比索 = "ARS"  # 阿根廷比索
货币代码_智利比索 = "CLP"  # 智利比索
货币代码_哥伦比亚比索 = "COP"  # 哥伦比亚比索
货币代码_秘鲁索尔 = "PEN"  # 秘鲁索尔
货币代码_乌拉圭比索 = "UYU"  # 乌拉圭比索
货币代码_委内瑞拉玻利瓦尔 = "VES"  # 委内瑞拉玻利瓦尔
货币代码_巴基斯坦卢比 = "PKR"  # 巴基斯坦卢比
货币代码_孟加拉塔卡 = "BDT"  # 孟加拉塔卡
货币代码_斯里兰卡卢比 = "LKR"  # 斯里兰卡卢比
货币代码_尼泊尔卢比 = "NPR"  # 尼泊尔卢比
货币代码_伊朗里亚尔 = "IRR"  # 伊朗里亚尔
货币代码_伊拉克第纳尔 = "IQD"  # 伊拉克第纳尔
货币代码_叙利亚镑 = "SYP"  # 叙利亚镑
货币代码_约旦第纳尔 = "JOD"  # 约旦第纳尔
货币代码_黎巴嫩镑 = "LBP"  # 黎巴嫩镑
货币代码_科威特第纳尔 = "KWD"  # 科威特第纳尔
货币代码_卡塔尔里亚尔 = "QAR"  # 卡塔尔里亚尔
货币代码_阿曼里亚尔 = "OMR"  # 阿曼里亚尔
货币代码_巴林第纳尔 = "BHD"  # 巴林第纳尔
货币代码_阿尔及利亚第纳尔 = "DZD"  # 阿尔及利亚第纳尔
货币代码_摩洛哥迪拉姆 = "MAD"  # 摩洛哥迪拉姆
货币代码_突尼斯第纳尔 = "TND"  # 突尼斯第纳尔
货币代码_利比亚第纳尔 = "LYD"  # 利比亚第纳尔
货币代码_苏丹镑 = "SDG"  # 苏丹镑